@@ -1,4 +1,4 @@
-// bsload.cc for bbsload - an tool for display the load in X11.
+// bsload.cc for bbsload - a tool to display the load in X11.
 //
 //  Copyright (c) 1998-2000 by John Kennis, jkennis@chello.nl
 //
@@ -21,6 +21,9 @@
 
 #include "bbsload.hh"
 
+#define NETBUFSIZE 255
+#define BYTESINAKILOBIT 125.0	// Number of bytes in a Kilobit (float)
+
 CheckLoad::CheckLoad(ToolWindow *toolwindow) {
   bbtool=toolwindow;
   timer=new BTimer(bbtool->getCurrentScreenInfo()->getBaseDisplay(),this) ;
@@ -129,6 +132,65 @@ void CheckLoad::timeout()
         }
     }
     fclose(fp);
+    
+    char s[NETBUFSIZE], *ch;
+#ifdef  _GNU_SOURCE
+    unsigned long long totalin=0,totalin_old=0,totalout=0,totalout_old=0;
+#else
+    unsigned long totalin=0,totalin_old=0,totalout=0,totalout_old=0;
+#warning "Use the GNU Compiler Collection for better accuracy in your integers."
+#endif
+    
+    // Read the network interface from /proc/net/dev
+    // This is GNU/Linux specific code. I have access to SUN and
+    // FreeBSD kernels, so I will hopefully update this to be
+    // cross-platform soon. Thanks to the fluxbox team for the
+    // code which this is based on. Data in /proc/net/dev is cumulative,
+    // so we must subtract the last reading. "Sam Halliday" <fommil@yahoo.ie>
+    totalin_old=net.intotal;
+    totalout_old=net.outtotal;
+    
+    if (!(fp = fopen("/proc/net/dev", "r")))
+    {
+     fprintf(stderr, "Open /proc/net/dev failed. Is a Linux /proc mounted?");
+     broken=True;
+    }
+    else
+    {
+     while (!feof(fp))
+     {
+      fgets (s, NETBUFSIZE-1, fp);
+      if (strstr(s, bbtool->getResource()->report.netname))
+      {
+       ch = strchr(s,':');
+#ifdef  _GNU_SOURCE
+       if(ch) sscanf(++ch, "%Lu %*d %*d %*d %*d %*d %*d %*d %Lu", &net.intotal,
+       &net.outtotal);
+#else
+       if(ch) sscanf(++ch, "%u %*d %*d %*d %*d %*d %*d %*d %u", &net.intotal,
+       &net.outtotal);
+#endif
+       redraw=true;
+       break;
+      }
+     }
+    }
+    fclose(fp);
+    // We need to consider the difference in bytes, network card speed and our
+    // delay in checking this value.
+    // BUG: the first reading will always be random as net.intotal and
+    // net.outtotal will be random numbers on startup.
+    // BUG: the 'total' numbers get quite big, and will eventually
+    // overrun the integer limit. This will only mess up one reading
+    // and will fix itself on the next 'check_delay'
+    net.inchange=(float)(net.intotal-totalin_old)/
+                 ((bbtool->getResource()->report.netspeed)*BYTESINAKILOBIT
+		 *(bbtool->getResource()->report.check_delay));
+    net.outchange=(float)(net.outtotal-totalout_old)/
+                 ((bbtool->getResource()->report.netspeed)*BYTESINAKILOBIT
+		 *(bbtool->getResource()->report.check_delay));
+    // printf("DEBUG: %d\t%d\t%f\t%f\n",net.intotal,net.outtotal,net.inchange,net.outchange);
+           
     if (redraw)
       bbtool->Redraw();
 }
@@ -207,7 +269,7 @@ void ToolWindow::MakeWindow(bool reconfigure)
                4*resource->frame.bevelWidth)*2;
 
   label.seperator_width=label.space_width=0;
-  for (i=0;i<13;i++) label.width[i]=0;
+  for (i=0;i<15;i++) label.width[i]=0;
   int extra_space=0;
   int label_counter=0;
 
@@ -260,6 +322,14 @@ void ToolWindow::MakeWindow(bool reconfigure)
       label.width[12] =  XTextWidth(resource->label.font,"0.00",strlen("0.00"));
       label_counter++;
     }
+    if (resource->show.label_networkin) {
+      label.width[13] =  XTextWidth(resource->label.font,"0.00",strlen("0.00"));
+      label_counter++;
+    }
+    if (resource->show.label_networkout) {
+      label.width[14] =  XTextWidth(resource->label.font,"0.00",strlen("0.00"));
+      label_counter++;
+    }
     
     label.seperator_width = 
                        XTextWidth(resource->label.font,"/",strlen("/"));
@@ -273,7 +343,7 @@ void ToolWindow::MakeWindow(bool reconfigure)
     extra_space=resource->frame.bevelWidth;
   }
   label.total_width=(label_counter-1)*label.seperator_width+2*label.space_width;
-  for (i=0;i<13;i++) 
+  for (i=0;i<15;i++) 
     label.total_width+=label.width[i];
     
   int number_of_loadbars=0;
@@ -283,6 +353,8 @@ void ToolWindow::MakeWindow(bool reconfigure)
   if (resource->show.idlecpu) number_of_loadbars++;
   if (resource->show.nicecpu) number_of_loadbars++;
   if (resource->show.usercpu) number_of_loadbars++;
+  if (resource->show.networkin) number_of_loadbars++;
+  if (resource->show.networkout) number_of_loadbars++;
   if (resource->show.systemcpu) number_of_loadbars++;
   if (resource->show.totalused) number_of_loadbars++;
   if (resource->show.swapused) number_of_loadbars++;
@@ -625,7 +697,16 @@ void ToolWindow::Redraw()
        RedrawGauge(check_load->getCpu().idle,offset);
        offset++;    
     }
-
+    if (resource->show.networkin)
+    {
+       RedrawGauge(check_load->getNet().inchange,offset);
+       offset++;    
+    }
+    if (resource->show.networkout)
+    {
+       RedrawGauge(check_load->getNet().outchange,offset);
+       offset++;    
+    }
     if (resource->show.label)
     {
         char t[6];
@@ -726,6 +807,16 @@ void ToolWindow::Redraw()
           RedrawLabel(check_load->getCpu().idle,labelnr);
           labelnr++;
         }
+	if (resource->show.label_networkin)
+        {
+          RedrawLabel(check_load->getNet().inchange,labelnr);
+          labelnr++;
+        }
+	if (resource->show.label_networkout)
+        {
+          RedrawLabel(check_load->getNet().outchange,labelnr);
+          labelnr++;
+        }
     }    
         
     if (check_load->getBroken())
