@@ -228,6 +228,23 @@ void	Resource::CheckSettings() {
   }
   else
     bbtool->raised = True;
+
+  // These are the network card settings... there is nowhere else
+  // for them to go but here.
+  if (XrmGetResource(resource_db, "bbsload.netcard.name",
+                     "Bbsload.Netcard.Name", &value_type, &value)){
+   sscanf(value.addr,"%s", report.netname);
+  }
+  else  // if bbsload.netcard.name is not set, default to "eth0"
+   strcpy(report.netname,"eth0");
+  //  printf("DEBUG: %s\n",report.netname);
+  
+  if (XrmGetResource(resource_db, "bbsload.netcard.speed",
+                     "Bbsload.Netcard.Speed", &value_type, &value)){
+   sscanf(value.addr,"%d", &report.netspeed);
+  }
+  else // if bbsload.netcard.speed is not set, default to 10MBits/sec
+   report.netspeed=10;
 }
 
 
@@ -462,6 +479,14 @@ void	Resource::Show() {
                                    "Bbsload.Show.CpuIdle.Label",False);
   show.idlecpu = showGauge("bbsload.show.cpuIdle.gauge",
                              "Bbsload.Show.CpuIdle.Gauge",False);
+  show.label_networkin = showLabel("bbsload.show.networkin.label",
+                                   "Bbsload.Show.Networkin.Label",False);
+  show.networkin = showGauge("bbsload.show.networkin.gauge",
+                             "Bbsload.Show.Networkin.Gauge",False);
+  show.label_networkout = showLabel("bbsload.show.networkout.label",
+                                   "Bbsload.Show.Networkout.Label",False);
+  show.networkout = showGauge("bbsload.show.networkout.gauge",
+                             "Bbsload.Show.Networkout.Gauge",False);
   show.label_memused = showLabel("bbsload.show.memUsed.label",
                                  "Bbsload.Show.MemUsed.Label",False);
   show.memused = showGauge("bbsload.show.memUsed.gauge",
